@@ -1,6 +1,6 @@
 /*
  * Program name:  equake
- * Version:	  1.03.5
+ * Version:	  1.03.6
  * Source file:	  equake.c (main source file)
  * Description:	  Equake pulls data about earthquakes and displays it in interesting ways
  *
@@ -101,7 +101,7 @@ void setdefaults(struct Equake_Data *equakedata)
 
   equake_setprefs(equakedata);
 
-  if (getquakedata(equakedata, FIRST)==1)
+  if (getquakedata(equakedata, FIRST)>0)
     if (processdata(equakedata, HOURLY)==-1)
       perror("Failed to process data"); /* non fatal error, hopefully */
 }
@@ -117,7 +117,7 @@ int eventloop(struct Equake_Data *equakedata)
   /* lets refresh preferences, if user has changed it, we will now use the new values */
   equake_getprefs(equakedata);
 
-  if (getquakedata(equakedata, HOURLY)==1)
+  if (getquakedata(equakedata, HOURLY)>0)
     if (processdata(equakedata, HOURLY)==-1)
       perror("Failed to process data"); /* non fatal error, hopefully */
 
@@ -233,6 +233,8 @@ int getquakedata(struct Equake_Data *equakedata, int period)
     return 0;
   }
  
+  rv=0;
+
   switch (period)
   {
     case DAILY:
@@ -244,7 +246,7 @@ int getquakedata(struct Equake_Data *equakedata, int period)
       }
       /* re-initialize buffer */
       memset(equakedata->bufferdaily, 0, BUFFERSIZEDAILY);
-      receiveall(equakedata->sockfd, equakedata->bufferdaily, sizeof(equakedata->bufferdaily), period);
+      rv=receiveall(equakedata->sockfd, equakedata->bufferdaily, sizeof(equakedata->bufferdaily), period);
       break;
 
     case WEEKLY:
@@ -256,7 +258,7 @@ int getquakedata(struct Equake_Data *equakedata, int period)
       }
       /* re-initialize buffer */
       memset(equakedata->bufferweekly, 0, BUFFERSIZEWEEKLY);
-      receiveall(equakedata->sockfd, equakedata->bufferweekly, sizeof(equakedata->bufferweekly), period);
+      rv=receiveall(equakedata->sockfd, equakedata->bufferweekly, sizeof(equakedata->bufferweekly), period);
       break;
 
     default:
@@ -269,12 +271,28 @@ int getquakedata(struct Equake_Data *equakedata, int period)
 
       /* re-initialize buffer */
       memset(equakedata->buffer, 0, BUFFERSIZE);
-      receiveall(equakedata->sockfd, equakedata->buffer, sizeof(equakedata->buffer), period);
+      rv=receiveall(equakedata->sockfd, equakedata->buffer, sizeof(equakedata->buffer), period);
       break;
   }
   close(equakedata->sockfd);
 
-  return 1;
+  switch (rv)
+  {
+    case -1: /* error receiving data, errno is set but we don't care right now */
+      perror("error when receiving data");
+      return 0;
+      break;
+
+    case 0: /* remote side has closed connection, not an error, but we have received no data so we treat it as error here */
+      perror("remote side closed connection");
+      return 0;
+      break;
+
+    default: /* if > 0 then success, although if we received very little there may not be much to process */
+      return rv;
+      break;
+  }
+  
 }
 
 
