@@ -1,6 +1,6 @@
 /*
  * Program name:  equake
- * Version:	  1.03.5
+ * Version:	  1.03.6
  * Source file:	  equake_applet.c  
  * Description:	  Equake pulls data about earthquakes and displays it in interesting ways
  *
@@ -512,7 +512,7 @@ static void do_update(XfcePanelPlugin *applet, struct Equake_Data *equakedata)
   /* lets refresh preferences, if user has changed it, we will now use the new values */
   equake_getprefs(equakedata);
 
-  if (getquakedata(equakedata, HOURLY)==1)
+  if (getquakedata(equakedata, HOURLY)>0)
     if (processdata(equakedata, HOURLY)==-1)
       perror("Failed to process data"); /* non fatal error, hopefully */
 }
@@ -912,7 +912,7 @@ static void display_about_dialog(XfcePanelPlugin *applet, struct Equake_Data *eq
  */
 static void display_lastweek(XfcePanelPlugin *applet, struct Equake_Data *equakedata)
 {
-  if (getquakedata(equakedata, WEEKLY)==1)
+  if (getquakedata(equakedata, WEEKLY)>0)
   {
     if (processdata(equakedata, WEEKLY)==-1)
     {
@@ -926,7 +926,7 @@ static void display_lastweek(XfcePanelPlugin *applet, struct Equake_Data *equake
 
 static void display_lastday(XfcePanelPlugin *applet, struct Equake_Data *equakedata)
 {
-  if (getquakedata(equakedata, DAILY)==1)
+  if (getquakedata(equakedata, DAILY)>0)
   {
     if (processdata(equakedata, DAILY)==-1)
     {
@@ -940,7 +940,7 @@ static void display_lastday(XfcePanelPlugin *applet, struct Equake_Data *equaked
   
 static void display_lasthour(XfcePanelPlugin *applet, struct Equake_Data *equakedata)
 {
-  if (getquakedata(equakedata, HOURLY)==1)
+  if (getquakedata(equakedata, HOURLY)>0)
   {
     if (processdata(equakedata, HOURLY)==-1)
     {
