@@ -1,6 +1,6 @@
 /*
  * Program name:  equake
- * Version:	  1.03.5
+ * Version:	  1.03.6
  * Source file:	  equake_processdata.c
  * Description:	  Equake pulls data about earthquakes and displays it in interesting ways
  *
@@ -460,7 +460,7 @@ int render_equake_label(struct Equake_Data *equakedata)
       if (day==1)
       {
 	/* if we get here it means hourly update had no earthquakes>=monitormag, so we check daily update */
-	if (getquakedata(equakedata, DAILY)==1)
+	if (getquakedata(equakedata, DAILY)>0)
 	{
 	  if (processdata_daily(equakedata)>0)
 	  {
